package zxcvbn

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module ZxcvbnSource

Bindings to the zxcvbn password strength estimation library

Sourcemodule Match : sig ... end
Sourceval matches : string -> float * Match.t list

Return the overall password entropy estimation and the list of matches. The underlying C function expects a null terminated string so keep in mind that if the given string contains null chars, only the substring until the first null char will be evaluated.