package zxcvbn
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module ZxcvbnSource
Bindings to the zxcvbn password strength estimation library
Return the overall password entropy estimation and the list of matches. The underlying C function expects a null terminated string so keep in mind that if the given string contains null chars, only the substring until the first null char will be evaluated.